Takes a set of points and a buffer radius, and returns a polygon. Code modified from Elith and Hijmans SDM with R tutorial
background.shape.buffer(points, radius)A two column data frame with X and Y coordinates
Radius for circular buffers to draw around points, in meters.
A polygon shapefile.