Learn R Programming

ENMTools (version 1.0)

enmtools.hypervolume: Takes an emtools.species object and environmental layers, and constructs a hypervolume using the R package hypervolume

Description

Takes an emtools.species object and environmental layers, and constructs a hypervolume using the R package hypervolume

Usage

enmtools.hypervolume(
  species,
  env,
  samples.per.point = 10,
  reduction.factor = 0.1,
  method = "gaussian",
  ...
)

Arguments

species

An enmtools.species object

env

A stack of environmental rasters

samples.per.point

To be passed to hypervolume_gaussian

reduction.factor

To be passed to hypervolume_project

method

Method for constructing hypervolumes, defaults to "gaussian"

...

Extra parameters to be passed to hypervolume_gaussian

Value

An enmtools hypvervolume object containing a hypervolume object, a raster of suitability scores, the species name, and the occurrence data frame.

Examples

Run this code
# NOT RUN {
install.extras(repos='http://cran.us.r-project.org')
data(euro.worldclim)
data(iberolacerta.clade)
env <- euro.worldclim[[c(1,8,12,17)]]
if(requireNamespace("hypervolume", quietly = TRUE)) {
    monticola.hv <- enmtools.hypervolume(iberolacerta.clade$species$monticola, env = env)
}
# }

Run the code above in your browser using DataLab