Learn R Programming

ENMTools (version 1.0)

enmtools.maxent: Takes an emtools.species object with presence and background points, and builds a maxent model

Description

Takes an emtools.species object with presence and background points, and builds a maxent model

Usage

enmtools.maxent(
  species,
  env,
  test.prop = 0,
  nback = 1000,
  env.nback = 10000,
  report = NULL,
  overwrite = FALSE,
  rts.reps = 0,
  bg.source = "default",
  ...
)

Arguments

species

An enmtools.species object

env

A raster or raster stack of environmental data.

test.prop

Proportion of data to withhold randomly for model evaluation, or "block" for spatially structured evaluation.

nback

Number of background points to draw from range or env, if background points aren't provided

env.nback

Number of points to draw from environment space for environment space discrimination metrics.

report

Optional name of an html file for generating reports

overwrite

TRUE/FALSE whether to overwrite a report file if it already exists

rts.reps

The number of replicates to do for a Raes and ter Steege-style test of significance

bg.source

Source for drawing background points. If "points", it just uses the background points that are already in the species object. If "range", it uses the range raster. If "env", it draws points at randome from the entire study area outlined by the first environmental layer.

...

Arguments to be passed to maxent()

Value

An enmtools model object containing species name, model formula (if any), model object, suitability raster, marginal response plots, and any evaluation objects that were created.

Examples

Run this code
# NOT RUN {
install.extras(repos='http://cran.us.r-project.org')
data(euro.worldclim)
data(iberolacerta.clade)
if(requireNamespace("rJava", quietly = TRUE)) {
    enmtools.maxent(iberolacerta.clade$species$monticola, env = euro.worldclim)
}
# }

Run the code above in your browser using DataLab