Proportion of data to withhold randomly for model evaluation, or "block" for spatially structured evaluation.
eval
Determines whether model evaluation should be done. Turned on by default, but moses turns it off to speed things up.
nback
Number of background points to draw from range or env, if background points aren't provided
env.nback
Number of points to draw from environment space for environment space discrimination metrics.
report
Optional name of an html file for generating reports
overwrite
TRUE/FALSE whether to overwrite a report file if it already exists
rts.reps
The number of replicates to do for a Raes and ter Steege-style test of significance
bg.source
Source for drawing background points. If "points", it just uses the background points that are already in the species object. If "range", it uses the range raster. If "env", it draws points at randome from the entire study area outlined by the first environmental layer.
...
Arguments to be passed to rf()
Value
An enmtools model object containing species name, model formula (if any), model object, suitability raster, marginal response plots, and any evaluation objects that were created.