Learn R Programming

ENMTools (version 1.0)

interactive.plot.enmtools.model: Plot an enmtools.model object on an interactive map

Description

Function that take an enmtools.model object and plots an interactive map of the presence points, background points (if applicable), and species suitability map. This function uses leaflet for mapping and will only function properly if you have an active internet connection.

Usage

# S3 method for enmtools.model
interactive.plot(
  x,
  map.provider = "Esri.WorldPhysical",
  cluster.points = FALSE,
  raster.opacity = 1,
  ...
)

Arguments

x

entools.model object to plot

map.provider

Name of a map provider for the underlying interactive base map. Default is "Esri.WorldPhysical", and attractive topographic map with no place labels. A preview of all map provider options can be viewed at http://leaflet-extras.github.io/leaflet-providers/preview/

cluster.points

Should points be clustered? If TRUE, points close together will be grouped into clusters that can be interactively expanded by clicking on them.

raster.opacity

Specifies the opacity level of the suitability raster.

...

other arguments (not used currently)

Value

An interactive leaflet plot depicting the predictions and data from the enmtools.model object.