Function that take an enmtools.species object and plots an
interactive map of the presence points, background points (if applicable), and
species range raster (if applicable). This function uses leaflet for mapping
and will only function properly if you have an active internet connection.
# S3 method for enmtools.species
interactive.plot(
x,
map.provider = "Esri.WorldPhysical",
cluster.points = FALSE,
...
)entools.species object to plot
Name of a map provider for the underlying interactive base map. Default is "Esri.WorldPhysical", and attractive topographic map with no place labels. A preview of all map provider options can be viewed at http://leaflet-extras.github.io/leaflet-providers/preview/
Should points be clustered? If TRUE, points close together will be grouped into clusters that can be interactively expanded by clicking on them.
other arguments (not used currently)
An interactive leaflet plot visualizing the data present in the species object.